library IEEE;
library work;

use IEEE.STD_LOGIC_1164.ALL;
use IEEE.NUMERIC_STD.ALL;

--! Packages from IP cores
--use work.wishbone_pkg.ALL;
--use work.i2c_slave_pkg.ALL;
--use work.m25p32_pkg.ALL;
--use work.multiboot_pkg.ALL;
--use work.rtm_detector_pkg.ALL;

package image1_top_pkg is

   constant c_NUMBER_OF_CHANNELS : NATURAL := 6;

   component image1_top
   generic(g_NUMBER_OF_CHANNELS : NATURAL := 6);
   port (FPGA_CLK_P        : in STD_LOGIC;
         FPGA_CLK_N        : in STD_LOGIC;

         led_pw_o          : out STD_LOGIC;
         led_err_o         : out STD_LOGIC;
         led_ttl_o         : out STD_LOGIC;
         led_o_front       : out STD_LOGIC_VECTOR(g_NUMBER_OF_CHANNELS downto 1);
         led_o_rear        : out STD_LOGIC_VECTOR(g_NUMBER_OF_CHANNELS downto 1);
         pulse_i_front     : in  STD_LOGIC_VECTOR(g_NUMBER_OF_CHANNELS downto 1);
         pulse_o_front     : out STD_LOGIC_VECTOR(g_NUMBER_OF_CHANNELS downto 1);
         pulse_i_rear      : in  STD_LOGIC_VECTOR(g_NUMBER_OF_CHANNELS downto 1);
         pulse_o_rear      : out STD_LOGIC_VECTOR(g_NUMBER_OF_CHANNELS downto 1);
         inv_i             : in  STD_LOGIC_VECTOR(4 downto 1);
         inv_o             : out STD_LOGIC_VECTOR(4 downto 1);
         --! Lines for the i2c_slave
         SCL_I             : in  STD_LOGIC;
         SCL_O             : out STD_LOGIC;
         SCL_OE            : out STD_LOGIC;
         SDA_I             : in  STD_LOGIC;
         SDA_O             : out STD_LOGIC;
         SDA_OE            : out STD_LOGIC;
         FPGA_GA           : in  STD_LOGIC_VECTOR(4 downto 0);
         FPGA_GAP          : in  STD_LOGIC;
         --! Pins of the SPI interface to write into the Flash memory
         FPGA_PROM_CCLK    : out STD_LOGIC;
         FPGA_PROM_CSO_B_N : out STD_LOGIC;
         FPGA_PROM_DIN     : in  STD_LOGIC;
         FPGA_PROM_MOSI    : out STD_LOGIC;

         --! This LED will show the status of the PLL
         led_link_up_o     : out STD_LOGIC;
         led_pps_o         : out STD_LOGIC;
         led_wr_ok_o       : out STD_LOGIC;
         fpga_o_en         : out STD_LOGIC;
         fpga_o_blo_en     : out STD_LOGIC;
         fpga_o_ttl_en     : out STD_LOGIC;
         fpga_o_inv_en     : out STD_LOGIC;
         level             : in  STD_LOGIC;
         switch_i          : in  STD_LOGIC;   --! General enable
         manual_rst_n_o    : out STD_LOGIC;   --! It allows power sequencing of the
         --! 24V rail after a security given
         --! delay
         FPGA_RTMM         : in STD_LOGIC_VECTOR(2 downto 0);
         FPGA_RTMP         : in STD_LOGIC_VECTOR(2 downto 0));
   end component;

   type t_pulse_vector is
      record
         FRONT : STD_LOGIC_VECTOR(c_NUMBER_OF_CHANNELS - 1 downto 0);
         REAR  : STD_LOGIC_VECTOR(c_NUMBER_OF_CHANNELS - 1 downto 0);
      end record;
   subtype t_pulse_led_vector is t_pulse_vector;

   type t_fpga_en is
      record
         GEN    : STD_LOGIC;
         BLO    : STD_LOGIC;
         TTL    : STD_LOGIC;
         INV    : STD_LOGIC;
      end record;

   type t_I2C_master_out is
      record
         SCL  : STD_LOGIC;
         SDA  : STD_LOGIC;
      end record;
   subtype t_I2C_slave_in is t_I2C_master_out;

   type t_I2C_master_in is
      record
         SDA  : STD_LOGIC;
      end record;
   subtype t_I2C_slave_out is t_I2C_master_in;

   type t_SPI_master_out is
      record
         CCLK    : STD_LOGIC;
         CSO_B_N : STD_LOGIC;
         MOSI    : STD_LOGIC;
      end record;
   subtype t_SPI_slave_in is t_SPI_master_out;

   type t_SPI_master_in is
      record
         DIN     : STD_LOGIC;
      end record;
   subtype t_SPI_slave_out is t_SPI_master_in;

   type t_RTM_id is
      record
         RTMM : STD_LOGIC_VECTOR(2 downto 0);
         RTMP : STD_LOGIC_VECTOR(2 downto 0);
      end record;

end image1_top_pkg;

package body image1_top_pkg is
end image1_top_pkg;
